package
Version:
v0.0.0-...-a77dc41
Opens a new window with list of versions in this module.
Published: Dec 13, 2021
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
func GetQRCodeIE1() []byte
GetQRCodeIE1 return the prefixed code from dcc-testdata/ie/2DCode/Raw/1.json.PREFIX
Source Files
¶
Click to show internal directories.
Click to hide internal directories.